@@ -11,8 +11,10 @@ import numpy as np
 from scipy import interpolate
 from tqdm import tqdm
 
-from .abund import Abund, elements as abund_elem
-from .data_structure import Collection, CollectionFactory, astype, array, this, oneof
+from .abund import Abund
+from .abund import elements as abund_elem
+from .data_structure import (Collection, CollectionFactory, array, astype,
+                             oneof, this)
 
 logger = logging.getLogger(__name__)
 
@@ -812,7 +814,7 @@ class Grid:
             points = [p for m, p in zip(mask, points) if m]
             target = [t for m, t in zip(mask, target) if m]
             idx = [slice(None, None) if m else 0 for m in mask]
-            grid = grid[idx]
+            grid = grid[tuple(idx)]
 
         method = "order"
         if method == "grid":
