@@ -2,23 +2,21 @@ import logging
 import os.path
 import platform
 import sys
-from copy import copy
 from datetime import datetime as dt
 
 import numpy as np
-from numpy.core.numeric import count_nonzero
-from scipy.io import readsav
 from scipy.constants import speed_of_light
+from scipy.io import readsav
 
 from . import __file_ending__, __version__, echelle, persistence
-from .abund import Abund, elements as abund_elem
+from .abund import Abund
+from .abund import elements as abund_elem
 from .atmosphere.atmosphere import Atmosphere
+from .data_structure import *
 from .iliffe_vector import Iliffe_vector
 from .linelist.linelist import LineList
 from .nlte import NLTE
 
-from .data_structure import *
-
 logger = logging.getLogger(__name__)
 
 
@@ -226,8 +224,8 @@ class SME_Structure(Parameters):
         super().__init__(**kwargs)
 
         if wind is not None and self.wave is not None:
-            wind = np.array([0, *(wind + 1)])
-            self.wave = Iliffe_vector(values=self.wave.ravel(), index=wind)
+            wind = wind + 1
+            self.wave = Iliffe_vector(self.wave.ravel(), offsets=wind)
 
         self.spec = kwargs.get("sob", None)
         self.uncs = kwargs.get("uob", None)
@@ -450,9 +448,7 @@ class SME_Structure(Parameters):
     def _cscale(self, value):
         if self.cscale_type in ["spline", "spline+mask"]:
             if not isinstance(value, Iliffe_vector):
-                self.__cscale = (
-                    Iliffe_vector(values=value) if value is not None else None
-                )
+                self.__cscale = vector(self, value)
             else:
                 self.__cscale = value
         else:
